import React, { useEffect, useRef, useState } from "react";
import { Graph, Node } from "@antv/x6";
import { Button, Dropdown, MenuProps, Input } from "antd";
import {
  CaretRightOutlined,
  DeleteFilled,
  DeleteOutlined,
} from "@ant-design/icons";

export default ({
  node,
  graph,
  img,
  items,
  hovered,
  selected,
}: {
  node: Node;
  graph: Graph;
  img: string | React.ReactNode;
  items: MenuProps["items"];
  hovered: boolean;
  selected: boolean;
}) => {
  const { name, type } = node.getData();

  const handleDelete = () => {
    graph.removeNode(node);
  };

  return (
    <>
      <div
        className="w-full flex justify-end absolute top--34px left-0"
        style={{ display: hovered || selected ? "flex" : "none" }}
      >
        <Button
          type="text"
          className="text-primary-dark"
          icon={<CaretRightOutlined />}
          onClick={handleDelete}
        />
        <Button
          type="text"
          className="text-primary-dark"
          icon={<DeleteFilled />}
          onClick={handleDelete}
        />
        <Dropdown menu={{ items }} overlayStyle={{ width: 120 }}>
          <Button
            type="text"
            className="text-primary-dark"
            icon={<i className="iconfont icon-gengduo" />}
          />
        </Dropdown>
      </div>
      {type ? (
        <div className="flex items-center leading-100px px-20px">
          {typeof img === "string" ? (
            <img src={img} alt="logo" className="w-50px" />
          ) : (
            img
          )}
          <div className="ml-10px">
            <div className="text-#333 text-12px">{name}</div>
          </div>
        </div>
      ) : (
        <>
          <div className="w-full h-full relative flex items-center justify-center">
            {typeof img === "string" ? (
              <img src={img} alt="logo" className="w-50px" />
            ) : (
              img
            )}
          </div>
          <div className="absolute w-full bottom--32px text-center text-#222">
            {name}
          </div>
        </>
      )}
    </>
  );
};
