import {
  FileAddOutlined,
  LayoutOutlined,
  PlusCircleFilled,
  RedoOutlined,
  UndoOutlined,
  ZoomInOutlined,
  ZoomOutOutlined,
} from "@ant-design/icons";
import { Button, Divider, Dropdown, Tooltip, Popover } from "antd";
import NodeMenu from "@/components/NodeMenu";
import type { MenuProps } from "antd/lib";
import { useRef, useEffect } from "react";
import { MiniMap } from "@antv/x6-plugin-minimap";
import { useModel } from "umi";

export default function index() {
  const minimapRef = useRef<HTMLDivElement>(null);
  const { graph } = useModel("flowModel");

  const zoomItems: MenuProps["items"] = [
    { key: "1", label: "25%" },
    { key: "2", label: "75%" },
    { key: "3", label: "100%" },
    { key: "4", label: "200%" },
    { key: "5", type: "divider" },
    { key: "6", label: "自适应" },
  ];

  useEffect(() => {
    if (graph && minimapRef.current) {
      const minimap = new MiniMap({
        container: minimapRef.current,
        width: 144,
        height: 100,
        padding: 10,
        scalable: true,
        minScale: 0.2,
        maxScale: 2,
        graphOptions: {
          background: {
            color: "#e9ebf0",
          },
        },
      });
      graph.use(minimap);
    }
  }, [graph, minimapRef.current]);

  const handleAddNotice = () => {
    const { width = 100, height = 100 } = graph?.getGraphArea() || {};
    graph?.addNode({ 
      shape: 'notice-node',
      zIndex: -1,
      position: {
        x: width / 2 - 150,
        y: height / 2 - 100,
      },
      data: {
        name: '',
        text: ''
      }
    });
  }

  return (
    <div className="absolute left-32px bottom-32px z-2 flex gap-12px">
      <div className="w-120px h-40px rounded-12px bg-#fff box-shadow-sm flex items-center justify-between px-12px">
        <Button type="text" icon={<ZoomInOutlined />} />
        <Dropdown
          menu={{
            items: zoomItems,
            style: { width: "160px", transform: "translate(-65px, -10px)" },
          }}
        >
          <span>100%</span>
        </Dropdown>
        <Button type="text" icon={<ZoomOutOutlined />} />
      </div>

      <div
        className="absolute w-144px h-100px bg-#e9ebf0 top--110px rounded-12px overflow-hidden"
        ref={minimapRef}
      ></div>

      <div className="w-60px h-40px rounded-12px bg-#fff box-shadow-sm flex items-center justify-between px-12px">
        <Button type="text" icon={<i className="iconfont icon-undo" />} disabled={true} />
        <Button type="text" icon={<i className="iconfont icon-redo" />} />
      </div>

      <div className="w-260px h-40px rounded-12px bg-#fff box-shadow-sm flex items-center justify-between px-12px">
        <Popover
          content={<NodeMenu graph={graph} />}
          trigger="click"
          placement="top"
          arrow={false}
        >
          <Button type="text" icon={<PlusCircleFilled />}>
            添加节点
          </Button>
        </Popover>
        <Tooltip title="添加文本">
          <Button type="text" icon={<FileAddOutlined />} onClick={handleAddNotice} />
        </Tooltip>
        <Divider type="vertical" />
        <Tooltip title="指针模式">
          <Button
            type="text"
            icon={<i className="iconfont icon-24gl-pointer" />}
          />
        </Tooltip>
        <Tooltip title="手模式">
          <Button type="text" icon={<i className="iconfont icon-shou1" />} />
        </Tooltip>
        <Divider type="vertical" />
        <Tooltip title="调整布局">
          <Button type="text" icon={<LayoutOutlined />} />
        </Tooltip>
      </div>
    </div>
  );
}
